<?php

















class HTMLForm implements HTMLElement
{
const HTTP_METHOD_POST='post';
const HTTP_METHOD_GET='get';

const SMALL_CSS_CLASS='fieldset-mini';
const NORMAL_CSS_CLASS='fieldset-content';

private static $instance_id=0;




private $constraints=array();



private $fieldsets=array();



private $buttons=array();



private $html_id='';



private $target='';



private $method=self::HTTP_METHOD_POST;



private $css_class=self::NORMAL_CSS_CLASS;



private static $js_already_included=false;



private $validation_error_messages=array();



private $template=null;

private $enable_captcha_protection;







public function __construct($html_id,$target='',$enable_captcha_protection=true)
{
$this->enable_captcha_protection=$enable_captcha_protection;
$this->set_html_id($html_id);
$this->set_target($target);

if($this->enable_captcha_protection)
$this->add_catpcha_protection();

self::$instance_id++;
}

private function add_catpcha_protection()
{
$captcha_protection_fieldset=new FormFieldsetHTML('captcha_fieldset');
$captcha_protection_fieldset->add_field(new FormFieldCaptcha());
$this->add_fieldset($captcha_protection_fieldset);
}

public function move_captcha_protection_in_last_position()
{
try{
$this->fieldsets[]=$this->fieldsets[0];
unset($this->fieldsets[0]);
}catch(FormBuilderException $e){
}
}





public function add_fieldset(FormFieldset $fieldset)
{
$fieldset->set_form_id($this->html_id);
$this->fieldsets[]=$fieldset;
}





public function add_constraint(FormConstraint $constraint)
{
$this->constraints[]=$constraint;
}





public function add_button(FormButton $button)
{
$button->set_form_id($this->html_id);
$this->buttons[]=$button;
}







public function get_value($field_id,$default_value=null)
{
try{
$field=$this->get_field_by_id($field_id);

if($field->is_disabled()&&$default_value!==null)
{
$field->set_value($default_value);
}
else if($field->is_disabled()&&$default_value==null)
{
throw new FormBuilderDisabledFieldException($field->get_id(),$field->get_value());
}
return $field->get_value();
}catch(FormBuilderException $e){
return $default_value;
}
}






public function field_is_disabled($field_id)
{
$field=$this->get_field_by_id($field_id);
if($field->is_disabled())
{
return true;
}
return false;
}






public function has_field($field_id){
try{
$this->field_is_disabled($field_id);
}catch(FormBuilderException $ex){
return false;
}
return true;
}

public function get_field_by_id($field_id)
{
foreach($this->fieldsets as $fieldset)
{
if($fieldset->has_field($field_id))
{
return $fieldset->get_field($field_id);
}
}
throw new FormBuilderException('The field "'.$field_id.
'" doesn\'t exists in the "'.$this->html_id.'" form');
}

private function get_fieldset_by_id($fieldset_id)
{
foreach($this->fieldsets as $fieldset)
{
if($fieldset->get_id()==$fieldset_id)
{
return $fieldset;
}
}
throw new FormBuilderException('The fieldset "'.$fieldset_id.
'" doesn\'t exists in the "'.$this->html_id.'" form');
}





public function display()
{
if($this->enable_captcha_protection)
$this->move_captcha_protection_in_last_position();

$template=$this->get_template_to_use();

$template->put_all(array(
'C_JS_NOT_ALREADY_INCLUDED'=>!self::$js_already_included,
'C_HAS_REQUIRED_FIELDS'=>(self::$instance_id==1)?$this->has_required_fields():false,
'C_TARGET'=>!empty($this->target),
'FORMCLASS'=>$this->css_class,
'TARGET'=>$this->target,
'HTML_ID'=>$this->html_id,
'L_REQUIRED_FIELDS'=>LangLoader::get_message('form.explain_required_fields','status-messages-common'),
'C_VALIDATION_ERROR'=>count($this->validation_error_messages),
'TITLE_VALIDATION_ERROR_MESSAGE'=>LangLoader::get_message('form.validation_error','status-messages-common'),
'METHOD'=>$this->method
));

foreach($this->validation_error_messages as $error_message)
{
if(!empty($error_message))
{
$template->assign_block_vars('validation_error_messages',array(
'ERROR_MESSAGE'=>$error_message
));
}
}

self::$js_already_included=true;

foreach($this->fieldsets as $fieldset)
{
$template->assign_block_vars('fieldsets',array(),array(
'FIELDSET'=>$fieldset->display()
));


foreach($fieldset->get_onsubmit_validations()as $constraints)
{
foreach($constraints as $constraint)
{
$template->assign_block_vars('check_constraints',array(
'ONSUBMIT_CONSTRAINTS'=>$constraint
));
}
}
}

if(count($this->buttons)>0)
{
$buttons_fieldset=new FormFieldsetSubmit('fbuttons');
$buttons_fieldset->set_form_id($this->html_id);
foreach($this->buttons as $button)
{
$buttons_fieldset->add_element($button);
}
$template->assign_block_vars('fieldsets',array(),array(
'FIELDSET'=>$buttons_fieldset->display()
));
}

return $template;
}




private function get_template_to_use()
{
if($this->template!==null)
{
return $this->template;
}
else
{
return new FileTemplate('framework/builder/form/Form.tpl');
}
}

private function has_required_fields()
{
foreach($this->fieldsets as $fieldset)
{
foreach($fieldset->get_fields()as $field)
{
if($field->is_required())
{
return true;
}
}
}
return false;
}






public function validate()
{
$this->handle_disabled_fields();

$validation_result=true;

foreach($this->fieldsets as $fieldset)
{
if(!$fieldset->validate())
{
$validation_error_message=$fieldset->get_validation_error_messages();
if(!empty($validation_error_message))
{
$this->validation_error_messages=array_merge($this->validation_error_messages,(array)$validation_error_message);
}
$validation_result=false;
}
}
return $validation_result;
}





public function set_html_id($html_id)
{
$this->html_id=$html_id;
}

public function get_html_id()
{
return $this->html_id;
}





public function set_target($target)
{
if($target instanceof Url)
{
$this->target=$target->rel();
}
else
{
$this->target=$target;
}
}






public function set_css_class($css_class)
{
$this->css_class=$css_class;
}





public function set_method($method)
{
if($method==self::HTTP_METHOD_POST)
{
$this->method=self::HTTP_METHOD_POST;
}
else
{
$this->method=self::HTTP_METHOD_GET;
}
}






public function set_template(Template $template)
{
$this->template=$template;
}

private function handle_disabled_fields()
{
$this->enable_all_fields();
$request=AppContext::get_request();

$disabled_fieldsets_str=$request->get_string($this->html_id.'_disabled_fieldsets','');
$disabled_fieldsets_str=trim($disabled_fieldsets_str,'|');
if($disabled_fieldsets_str!='')
{
$disabled_fieldsets=explode('|',$disabled_fieldsets_str);
foreach($disabled_fieldsets as $fieldset_id)
{
try{
$fieldset=$this->get_fieldset_by_id(str_replace($this->html_id.'_','',$fieldset_id));
$fieldset->disable();
}catch(FormBuilderException $e){
}
}
}

$disabled_fields_str=$request->get_string($this->html_id.'_disabled_fields');
$disabled_fields_str=trim($disabled_fields_str,'|');
if($disabled_fields_str!='')
{
$disabled_fields=explode('|',$disabled_fields_str);
foreach($disabled_fields as $field_id)
{
try{
$field=$this->get_field_by_id(str_replace($this->html_id.'_','',$field_id));
$field->disable();
}catch(FormBuilderException $e){
}
}
}
}

private function enable_all_fields()
{
foreach($this->fieldsets as $fieldset)
{
$fieldset->enable();
}
}
}
?>
